Struct Lazy

struct Lazy { ... }

Lazy block buffer kind, which guarantees that buffer position always lies in the range of 0..=BlockSize.

Implementations

impl BufferKind for Lazy

impl Clone for Lazy

fn clone(self: &Self) -> Lazy

impl Copy for Lazy

impl Debug for Lazy

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for Lazy

fn default() -> Lazy

impl Freeze for Lazy

impl RefUnwindSafe for Lazy

impl Send for Lazy

impl Sync for Lazy

impl Unpin for Lazy

impl UnsafeUnpin for Lazy

impl UnwindSafe for Lazy

impl<T> Any for Lazy

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Lazy

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Lazy

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Lazy

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Lazy

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for Lazy

impl<T, U> Into for Lazy

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Lazy

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Lazy

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>