Struct Eager
struct Eager { ... }
Eager block buffer kind, which guarantees that buffer position
always lies in the range of 0..BlockSize.
Implementations
impl BufferKind for Eager
impl Clone for Eager
fn clone(self: &Self) -> Eager
impl Copy for Eager
impl Debug for Eager
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Eager
fn default() -> Eager
impl Freeze for Eager
impl RefUnwindSafe for Eager
impl Send for Eager
impl Sync for Eager
impl Unpin for Eager
impl UnsafeUnpin for Eager
impl UnwindSafe for Eager
impl<T> Any for Eager
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Eager
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Eager
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Eager
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Eager
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Same for Eager
impl<T, U> Into for Eager
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Eager
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Eager
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>